@@ -64,8 +64,6 @@ static GSList *watch_list = NULL;
 static unsigned int watch_id = 0;
 
 static GSList *update_list = NULL;
-static guint update_interval = G_MAXUINT;
-static guint update_timeout = 0;
 
 struct interface_data {
 	int index;
@@ -147,61 +145,6 @@ void vpn_rtnl_remove_watch(unsigned int id)
 	}
 }
 
-static void trigger_rtnl(int index, void *user_data)
-{
-	struct vpn_rtnl *rtnl = user_data;
-
-	if (rtnl->newlink) {
-		unsigned short type = __vpn_ipconfig_get_type_from_index(index);
-		unsigned int flags = __vpn_ipconfig_get_flags_from_index(index);
-
-		rtnl->newlink(type, index, flags, 0);
-	}
-}
-
-static GSList *rtnl_list = NULL;
-
-static gint compare_priority(gconstpointer a, gconstpointer b)
-{
-	const struct vpn_rtnl *rtnl1 = a;
-	const struct vpn_rtnl *rtnl2 = b;
-
-	return rtnl2->priority - rtnl1->priority;
-}
-
-/**
- * vpn_rtnl_register:
- * @rtnl: RTNL module
- *
- * Register a new RTNL module
- *
- * Returns: %0 on success
- */
-int vpn_rtnl_register(struct vpn_rtnl *rtnl)
-{
-	DBG("rtnl %p name %s", rtnl, rtnl->name);
-
-	rtnl_list = g_slist_insert_sorted(rtnl_list, rtnl,
-							compare_priority);
-
-	__vpn_ipconfig_foreach(trigger_rtnl, rtnl);
-
-	return 0;
-}
-
-/**
- * vpn_rtnl_unregister:
- * @rtnl: RTNL module
- *
- * Remove a previously registered RTNL module
- */
-void vpn_rtnl_unregister(struct vpn_rtnl *rtnl)
-{
-	DBG("rtnl %p name %s", rtnl, rtnl->name);
-
-	rtnl_list = g_slist_remove(rtnl_list, rtnl);
-}
-
 static const char *operstate2str(unsigned char operstate)
 {
 	switch (operstate) {
@@ -322,13 +265,6 @@ static void process_newlink(unsigned short type, int index, unsigned flags,
 					GINT_TO_POINTER(index), interface);
 	}
 
-	for (list = rtnl_list; list; list = list->next) {
-		struct vpn_rtnl *rtnl = list->data;
-
-		if (rtnl->newlink)
-			rtnl->newlink(type, index, flags, change);
-	}
-
 	for (list = watch_list; list; list = list->next) {
 		struct watch_data *watch = list->data;
 
@@ -346,7 +282,6 @@ static void process_dellink(unsigned short type, int index, unsigned flags,
 	struct rtnl_link_stats stats;
 	unsigned char operstate = 0xff;
 	const char *ifname = NULL;
-	GSList *list;
 
 	memset(&stats, 0, sizeof(stats));
 	extract_link(msg, bytes, NULL, &ifname, NULL, &operstate, &stats);
@@ -356,13 +291,6 @@ static void process_dellink(unsigned short type, int index, unsigned flags,
 						ifname, index, operstate,
 						operstate2str(operstate));
 
-	for (list = rtnl_list; list; list = list->next) {
-		struct vpn_rtnl *rtnl = list->data;
-
-		if (rtnl->dellink)
-			rtnl->dellink(type, index, flags, change);
-	}
-
 	switch (type) {
 	case ARPHRD_ETHER:
 	case ARPHRD_LOOPBACK:
@@ -428,7 +356,6 @@ static void extract_ipv6_route(struct rtmsg *msg, int bytes, int *index,
 static void process_newroute(unsigned char family, unsigned char scope,
 						struct rtmsg *msg, int bytes)
 {
-	GSList *list;
 	char dststr[INET6_ADDRSTRLEN], gatewaystr[INET6_ADDRSTRLEN];
 	int index = -1;
 
@@ -465,21 +392,12 @@ static void process_newroute(unsigned char family, unsigned char scope,
 
 		if (!IN6_IS_ADDR_UNSPECIFIED(&dst))
 			return;
-	} else
-		return;
-
-	for (list = rtnl_list; list; list = list->next) {
-		struct vpn_rtnl *rtnl = list->data;
-
-		if (rtnl->newgateway)
-			rtnl->newgateway(index, gatewaystr);
 	}
 }
 
 static void process_delroute(unsigned char family, unsigned char scope,
 						struct rtmsg *msg, int bytes)
 {
-	GSList *list;
 	char dststr[INET6_ADDRSTRLEN], gatewaystr[INET6_ADDRSTRLEN];
 	int index = -1;
 
@@ -516,14 +434,6 @@ static void process_delroute(unsigned char family, unsigned char scope,
 
 		if (!IN6_IS_ADDR_UNSPECIFIED(&dst))
 			return;
-	} else
-		return;
-
-	for (list = rtnl_list; list; list = list->next) {
-		struct vpn_rtnl *rtnl = list->data;
-
-		if (rtnl->delgateway)
-			rtnl->delgateway(index, gatewaystr);
 	}
 }
 
@@ -797,75 +707,71 @@ static const char *type2string(uint16_t type)
 
 static GIOChannel *channel = NULL;
 
-struct rtnl_request {
-	struct nlmsghdr hdr;
-	struct rtgenmsg msg;
-};
-#define RTNL_REQUEST_SIZE  (sizeof(struct nlmsghdr) + sizeof(struct rtgenmsg))
+#define RTNL_REQUEST_SIZE (NLMSG_HDRLEN + NLMSG_ALIGN(sizeof(struct rtgenmsg)))
 
 static GSList *request_list = NULL;
 static guint32 request_seq = 0;
 
-static struct rtnl_request *find_request(guint32 seq)
+static struct nlmsghdr *find_request(guint32 seq)
 {
 	GSList *list;
 
 	for (list = request_list; list; list = list->next) {
-		struct rtnl_request *req = list->data;
+		struct nlmsghdr *hdr = list->data;
 
-		if (req->hdr.nlmsg_seq == seq)
-			return req;
+		if (hdr->nlmsg_seq == seq)
+			return hdr;
 	}
 
 	return NULL;
 }
 
-static int send_request(struct rtnl_request *req)
+static int send_request(struct nlmsghdr *hdr)
 {
 	struct sockaddr_nl addr;
 	int sk;
 
 	debug("%s len %d type %d flags 0x%04x seq %d",
-				type2string(req->hdr.nlmsg_type),
-				req->hdr.nlmsg_len, req->hdr.nlmsg_type,
-				req->hdr.nlmsg_flags, req->hdr.nlmsg_seq);
+				type2string(hdr->nlmsg_type),
+				hdr->nlmsg_len, hdr->nlmsg_type,
+				hdr->nlmsg_flags, hdr->nlmsg_seq);
 
 	sk = g_io_channel_unix_get_fd(channel);
 
 	memset(&addr, 0, sizeof(addr));
 	addr.nl_family = AF_NETLINK;
 
-	return sendto(sk, req, req->hdr.nlmsg_len, 0,
+	return sendto(sk, hdr, hdr->nlmsg_len, 0,
 				(struct sockaddr *) &addr, sizeof(addr));
 }
 
-static int queue_request(struct rtnl_request *req)
+static int queue_request(struct nlmsghdr *hdr)
 {
-	request_list = g_slist_append(request_list, req);
+	request_list = g_slist_append(request_list, hdr);
 
 	if (g_slist_length(request_list) > 1)
 		return 0;
 
-	return send_request(req);
+	return send_request(hdr);
 }
 
 static int process_response(guint32 seq)
 {
-	struct rtnl_request *req;
+	struct nlmsghdr *hdr;
 
 	debug("seq %d", seq);
 
-	req = find_request(seq);
-	if (req) {
-		request_list = g_slist_remove(request_list, req);
-		g_free(req);
+	hdr = find_request(seq);
+	if (hdr) {
+		request_list = g_slist_remove(request_list, hdr);
+		g_free(hdr);
 	}
 
-	req = g_slist_nth_data(request_list, 0);
-	if (!req)
+	hdr = g_slist_nth_data(request_list, 0);
+	if (!hdr)
 		return 0;
 
-	return send_request(req);
+	return send_request(hdr);
 }
 
 static void rtnl_message(void *buf, size_t len)
@@ -879,7 +785,7 @@ static void rtnl_message(void *buf, size_t len)
 		if (!NLMSG_OK(hdr, len))
 			break;
 
-		debug("%s len %d type %d flags 0x%04x seq %d pid %d",
+		debug("%s len %u type %u flags 0x%04x seq %u pid %u",
 					type2string(hdr->nlmsg_type),
 					hdr->nlmsg_len, hdr->nlmsg_type,
 					hdr->nlmsg_flags, hdr->nlmsg_seq,
@@ -960,134 +866,65 @@ static gboolean netlink_event(GIOChannel *chan, GIOCondition cond, gpointer data
 
 static int send_getlink(void)
 {
-	struct rtnl_request *req;
+	struct nlmsghdr *hdr;
+	struct rtgenmsg *msg;
 
 	debug("");
 
-	req = g_try_malloc0(RTNL_REQUEST_SIZE);
-	if (!req)
-		return -ENOMEM;
+	hdr = g_malloc0(RTNL_REQUEST_SIZE);
 
-	req->hdr.nlmsg_len = RTNL_REQUEST_SIZE;
-	req->hdr.nlmsg_type = RTM_GETLINK;
-	req->hdr.nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
-	req->hdr.nlmsg_pid = 0;
-	req->hdr.nlmsg_seq = request_seq++;
-	req->msg.rtgen_family = AF_INET;
+	hdr->nlmsg_len = RTNL_REQUEST_SIZE;
+	hdr->nlmsg_type = RTM_GETLINK;
+	hdr->nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
+	hdr->nlmsg_pid = 0;
+	hdr->nlmsg_seq = request_seq++;
 
-	return queue_request(req);
+	msg = (struct rtgenmsg *) NLMSG_DATA(hdr);
+	msg->rtgen_family = AF_INET;
+
+	return queue_request(hdr);
 }
 
 static int send_getaddr(void)
 {
-	struct rtnl_request *req;
+	struct nlmsghdr *hdr;
+	struct rtgenmsg *msg;
 
 	debug("");
 
-	req = g_try_malloc0(RTNL_REQUEST_SIZE);
-	if (!req)
-		return -ENOMEM;
+	hdr = g_malloc0(RTNL_REQUEST_SIZE);
 
-	req->hdr.nlmsg_len = RTNL_REQUEST_SIZE;
-	req->hdr.nlmsg_type = RTM_GETADDR;
-	req->hdr.nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
-	req->hdr.nlmsg_pid = 0;
-	req->hdr.nlmsg_seq = request_seq++;
-	req->msg.rtgen_family = AF_INET;
+	hdr->nlmsg_len = RTNL_REQUEST_SIZE;
+	hdr->nlmsg_type = RTM_GETADDR;
+	hdr->nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
+	hdr->nlmsg_pid = 0;
+	hdr->nlmsg_seq = request_seq++;
 
-	return queue_request(req);
+	msg = (struct rtgenmsg *) NLMSG_DATA(hdr);
+	msg->rtgen_family = AF_INET;
+
+	return queue_request(hdr);
 }
 
 static int send_getroute(void)
 {
-	struct rtnl_request *req;
+	struct nlmsghdr *hdr;
+	struct rtgenmsg *msg;
 
 	debug("");
 
-	req = g_try_malloc0(RTNL_REQUEST_SIZE);
-	if (!req)
-		return -ENOMEM;
+	hdr = g_malloc0(RTNL_REQUEST_SIZE);
 
-	req->hdr.nlmsg_len = RTNL_REQUEST_SIZE;
-	req->hdr.nlmsg_type = RTM_GETROUTE;
-	req->hdr.nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
-	req->hdr.nlmsg_pid = 0;
-	req->hdr.nlmsg_seq = request_seq++;
-	req->msg.rtgen_family = AF_INET;
+	hdr->nlmsg_len = RTNL_REQUEST_SIZE;
+	hdr->nlmsg_type = RTM_GETROUTE;
+	hdr->nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
+	hdr->nlmsg_pid = 0;
+	hdr->nlmsg_seq = request_seq++;
 
-	return queue_request(req);
-}
+	msg = (struct rtgenmsg *) NLMSG_DATA(hdr);
+	msg->rtgen_family = AF_INET;
 
-static gboolean update_timeout_cb(gpointer user_data)
-{
-	__vpn_rtnl_request_update();
-
-	return TRUE;
-}
-
-static void update_interval_callback(guint min)
-{
-	if (update_timeout > 0)
-		g_source_remove(update_timeout);
-
-	if (min < G_MAXUINT) {
-		update_interval = min;
-		update_timeout = g_timeout_add_seconds(update_interval,
-						update_timeout_cb, NULL);
-	} else {
-		update_timeout = 0;
-		update_interval = G_MAXUINT;
-	}
-}
-
-static gint compare_interval(gconstpointer a, gconstpointer b)
-{
-	guint val_a = GPOINTER_TO_UINT(a);
-	guint val_b = GPOINTER_TO_UINT(b);
-
-	return val_a - val_b;
-}
-
-unsigned int __vpn_rtnl_update_interval_add(unsigned int interval)
-{
-	guint min;
-
-	if (interval == 0)
-		return 0;
-
-	update_list = g_slist_insert_sorted(update_list,
-			GUINT_TO_POINTER(interval), compare_interval);
-
-	min = GPOINTER_TO_UINT(g_slist_nth_data(update_list, 0));
-	if (min < update_interval) {
-		update_interval_callback(min);
-		__vpn_rtnl_request_update();
-	}
-
-	return update_interval;
-}
-
-unsigned int __vpn_rtnl_update_interval_remove(unsigned int interval)
-{
-	guint min = G_MAXUINT;
-
-	if (interval == 0)
-		return 0;
-
-	update_list = g_slist_remove(update_list, GINT_TO_POINTER(interval));
-
-	if (update_list)
-		min = GPOINTER_TO_UINT(g_slist_nth_data(update_list, 0));
-
-	if (min > update_interval)
-		update_interval_callback(min);
-
-	return min;
-}
-
-int __vpn_rtnl_request_update(void)
-{
-	return send_getlink();
+	return queue_request(hdr);
 }
 
 int __vpn_rtnl_init(void)
@@ -1158,14 +995,14 @@ void __vpn_rtnl_cleanup(void)
 	update_list = NULL;
 
 	for (list = request_list; list; list = list->next) {
-		struct rtnl_request *req = list->data;
+		struct nlmsghdr *hdr = list->data;
 
 		debug("%s len %d type %d flags 0x%04x seq %d",
-				type2string(req->hdr.nlmsg_type),
-				req->hdr.nlmsg_len, req->hdr.nlmsg_type,
-				req->hdr.nlmsg_flags, req->hdr.nlmsg_seq);
+				type2string(hdr->nlmsg_type),
+				hdr->nlmsg_len, hdr->nlmsg_type,
+				hdr->nlmsg_flags, hdr->nlmsg_seq);
 
-		g_free(req);
+		g_free(hdr);
 		list->data = NULL;
 	}
 
